@@ -493,8 +493,8 @@ KMenu* KMainWindow::customHelpMenu( bool showWhatsThis )
     K_D(KMainWindow);
     if (!d->helpMenu) {
         d->helpMenu = new KHelpMenu( this, QString(), showWhatsThis );
-        connect(d->helpMenu, SIGNAL( showAboutApplication()),
-                this, SLOT( showAboutApplication() ));
+        connect(d->helpMenu, SIGNAL(showAboutApplication()),
+                this, SLOT(showAboutApplication()));
     }
 
     return d->helpMenu->menu();
@@ -832,13 +832,9 @@ void KMainWindow::restoreWindowSize( const KConfigGroup & _cg )
 {
     K_D(KMainWindow);
 
-    int scnum = QApplication::desktop()->screenNumber(parentWidget());
+    int scnum = QApplication::desktop()->screenNumber(window());
     QRect desk = QApplication::desktop()->screenGeometry(scnum);
 
-    // if the desktop is virtual then use virtual screen size
-    if (QApplication::desktop()->isVirtualDesktop())
-      desk = QApplication::desktop()->screenGeometry(QApplication::desktop()->screen());
-
     QString geometryKey = QString::fromLatin1("geometry-%1-%2").arg(desk.width()).arg(desk.height());
     QByteArray geometry = _cg.readEntry( geometryKey, QByteArray() );
     // if first time run, center window
@@ -849,13 +845,9 @@ void KMainWindow::restoreWindowSize( const KConfigGroup & _cg )
 void KMainWindow::saveWindowSize( const KConfigGroup & _cg ) const
 {
     K_D(const KMainWindow);
-    int scnum = QApplication::desktop()->screenNumber(parentWidget());
+    int scnum = QApplication::desktop()->screenNumber(window());
     QRect desk = QApplication::desktop()->screenGeometry(scnum);
 
-    // if the desktop is virtual then use virtual screen size
-    if (QApplication::desktop()->isVirtualDesktop())
-        desk = QApplication::desktop()->screenGeometry(QApplication::desktop()->screen());
-
     // geometry is saved separately for each resolution
     QString geometryKey = QString::fromLatin1("geometry-%1-%2").arg(desk.width()).arg(desk.height());
     QByteArray geometry = saveGeometry();
@@ -866,13 +858,9 @@ void KMainWindow::saveWindowSize( const KConfigGroup & _cg ) const
 void KMainWindow::saveWindowSize( const KConfigGroup & _cg ) const
 {
     K_D(const KMainWindow);
-    int scnum = QApplication::desktop()->screenNumber(parentWidget());
+    int scnum = QApplication::desktop()->screenNumber(window());
     QRect desk = QApplication::desktop()->screenGeometry(scnum);
 
-    // if the desktop is virtual then use virtual screen size
-    if (QApplication::desktop()->isVirtualDesktop())
-        desk = QApplication::desktop()->screenGeometry(QApplication::desktop()->screen());
-
     int w, h;
 #if defined Q_WS_X11
     // save maximalization as desktop size + 1 in that direction
@@ -913,13 +901,9 @@ void KMainWindow::restoreWindowSize( const KConfigGroup & config )
         parseGeometry(true);
     } else {
         // restore the size
-        const int scnum = QApplication::desktop()->screenNumber(parentWidget());
+        const int scnum = QApplication::desktop()->screenNumber(window());
         QRect desk = QApplication::desktop()->screenGeometry(scnum);
 
-        // if the desktop is virtual then use virtual screen size
-        if (QApplication::desktop()->isVirtualDesktop())
-          desk = QApplication::desktop()->screenGeometry(QApplication::desktop()->screen());
-
         if ( d->defaultWindowSize.isNull() ) // only once
           d->defaultWindowSize = QRect(desk.width(), width(), desk.height(), height()); // store default values
         const QSize size( config.readEntry( QString::fromLatin1("Width %1").arg(desk.width()), 0 ),
