@@ -54,16 +54,16 @@
 #include <QtCore/QRegExp>
 #include <QtGui/QFont>
 #include <kcomponentdata.h>
+#include <klibrary.h>
 #include <kdemacros.h>
 #include <kstandarddirs.h>
-#include <kglobalsettings.h>
 #include <kglobal.h>
 #include <kconfig.h>
-#include <klibloader.h>
 #include <kapplication.h>
 #include <klocale.h>
 #include <kdebug.h>
 #include <kde_file.h>
+#include <ksavefile.h>
 
 #ifdef Q_OS_LINUX
 #include <sys/prctl.h>
@@ -87,6 +87,16 @@
 #include <kstartupinfo.h>
 #endif
 
+#ifdef Q_WS_X11
+static const char *extra_libs[] = {
+    "libkio.so.5",
+    "libkparts.so.4",
+#ifdef __KDE_HAVE_GCC_VISIBILITY
+    "libplasma.so.3"
+#endif
+};
+#endif
+
 // #define SKIP_PROCTITLE 1
 
 extern char **environ;
@@ -153,13 +163,6 @@ int kdeinit_x_errhandler( Display *, XErrorEvent *err );
 }
 #endif
 
-/* These are to link libkparts even if 'smart' linker is used */
-#include <kparts/plugin.h>
-extern "C" KParts::Plugin* _kinit_init_kparts() { return new KParts::Plugin(); }
-/* These are to link libkio even if 'smart' linker is used */
-#include <kio/authinfo.h>
-extern "C" KIO::AuthInfo* _kioslave_init_kio() { return new KIO::AuthInfo(); }
-
 #ifdef KDEINIT_OOM_PROTECT
 static int oom_pipe = -1;
 #endif
@@ -467,19 +470,22 @@ static pid_t launch(int argc, const char *_name, const char *args,
                     const char *tty=0, bool avoid_loops = false,
                     const char* startup_id_str = "0" ) // krazy:exclude=doublequote_chars
 {
-  QString lib;
-  QByteArray name;
-  QByteArray exec;
-
+    QString lib;
+    QByteArray name;
+    QByteArray exec;
     QString libpath;
     QByteArray execpath;
+
     if (_name[0] != '/') {
         name = _name;
         lib = QFile::decodeName(name);
         exec = name;
-        libpath = KLibLoader::findLibrary( QLatin1String("libkdeinit4_") + lib, *s_instance);
-        if( libpath.isEmpty())
-            libpath = KLibLoader::findLibrary(lib, *s_instance);
+        KLibrary klib(QLatin1String("libkdeinit4_") + lib, *s_instance );
+        libpath = klib.fileName();
+        if( libpath.isEmpty()) {
+            KLibrary klib(lib, *s_instance);
+            libpath = klib.fileName();
+        }
         execpath = execpath_avoid_loops(exec, envc, envs, avoid_loops);
     } else {
         name = _name;
@@ -505,8 +511,10 @@ static pid_t launch(int argc, const char *_name, const char *args,
             execpath = exec;
         }
     }
+#ifndef NDEBUG
     fprintf(stderr,"kdeinit4: preparing to launch %s\n", libpath.isEmpty()
         ? execpath.constData() : libpath.toUtf8().constData());
+#endif
     if (!args) {
         argc = 1;
     }
@@ -527,6 +535,11 @@ static pid_t launch(int argc, const char *_name, const char *args,
   if( !startup_id.none())
       init_startup_info( startup_id, name, envc, envs );
 #endif
+  // find out this path before forking, doing it afterwards
+  // crashes on some platforms, notably OSX
+#ifdef Q_WS_MAC
+  const QString bundlepath = s_instance->dirs()->findExe(QFile::decodeName(execpath));
+#endif
 
   d.errorMsg = 0;
   d.fork = fork();
@@ -552,9 +565,6 @@ static pid_t launch(int argc, const char *_name, const char *args,
      // we still want to execute `foo` even if the chdir() failed.
      if (cwd && *cwd) {
          (void)chdir(cwd);
-     } else {
-         const QByteArray docPath = QFile::encodeName(KGlobalSettings::documentPath());
-         (void)chdir(docPath.constData());
      }
 
      if( reset_env ) // KWRAPPER/SHELL
@@ -668,7 +678,6 @@ static pid_t launch(int argc, const char *_name, const char *args,
 
         QByteArray executable = execpath;
 #ifdef Q_WS_MAC
-        QString bundlepath = s_instance->dirs()->findExe(QFile::decodeName(executable));
         if (!bundlepath.isEmpty())
            executable = QFile::encodeName(bundlepath);
 #endif
@@ -1345,7 +1354,7 @@ static void handle_requests(pid_t waitForPid)
 
            if( WIFEXITED( exit_status )) // fix process return value
                exit_status = WEXITSTATUS(exit_status);
-           else if( WIFSIGNALED( exit_status ))
+           else if( WIFSIGNALED(exit_status))
                exit_status = 128 + WTERMSIG( exit_status );
            child_died(exit_pid, exit_status);
 
@@ -1569,6 +1578,42 @@ static void setupX()
 {
     XSetIOErrorHandler(kdeinit_xio_errhandler);
     XSetErrorHandler(kdeinit_x_errhandler);
+/*
+    Handle the tricky case of running via kdesu/su/sudo/etc. There the usual case
+    is that kdesu (etc.) creates a file with xauth information, sets XAUTHORITY,
+    runs the command and removes the xauth file after the command finishes. However,
+    dbus and kdeinit daemon currently don't clean up properly and keeping running.
+    Which means that running a KDE app via kdesu the second time talks to kdeinit
+    with obsolete xauth information, which makes it unable to connect to X or launch
+    any X11 applications.
+    Even fixing the cleanup probably wouldn't be sufficient, since it'd be possible to
+    launch one kdesu session, another one, exit the first one and the app from the second
+    session would be using kdeinit from the first one.
+    So the trick here is to duplicate the xauth file to another file in KDE's tmp
+    location, make the file have a consistent name so that future sessions will use it
+    as well, point XAUTHORITY there and never remove the file (except for possible
+    tmp cleanup).
+*/
+    if( !qgetenv( "XAUTHORITY" ).isEmpty()) {
+        QByteArray display = qgetenv( DISPLAY );
+        int i;
+        if((i = display.lastIndexOf('.')) > display.lastIndexOf(':') && i >= 0)
+            display.truncate(i);
+        display.replace(':','_');
+#ifdef __APPLE__
+        display.replace('/','_');
+#endif
+        QString xauth = s_instance->dirs()->saveLocation( "tmp" ) + QLatin1String( "xauth-" )
+            + QString::number( getuid()) + QLatin1String( "-" ) + QString::fromLocal8Bit( display );
+        KSaveFile xauthfile( xauth );
+        QFile xauthfrom( QFile::decodeName( qgetenv( "XAUTHORITY" )));
+        if( !xauthfrom.open( QFile::ReadOnly ) || !xauthfile.open( QFile::WriteOnly )
+            || xauthfile.write( xauthfrom.readAll()) != xauthfrom.size() || !xauthfile.finalize()) {
+            xauthfile.abort();
+        } else {
+            setenv( "XAUTHORITY", QFile::encodeName( xauth ), true );
+        }
+    }
 }
 
 // Borrowed from kdebase/kaudio/kaudioserver.cpp
@@ -1606,8 +1651,10 @@ static void secondary_child_handler(int)
 
 int main(int argc, char **argv, char **envp)
 {
+#ifndef _WIN32_WCE
     setlocale (LC_ALL, "");
     setlocale (LC_NUMERIC, "C");
+#endif
 
    pid_t pid;
    bool do_fork = true;
@@ -1745,21 +1792,26 @@ int main(int argc, char **argv, char **envp)
       init_kdeinit_socket();
    }
 #ifdef Q_WS_X11
-   if (!d.suicide && qgetenv("KDE_IS_PRELINKED").isEmpty())
-   {
-#ifdef __KDE_HAVE_GCC_VISIBILITY
-       QString extra = KStandardDirs::locate("lib", QLatin1String("libplasma.so.3"), *s_instance);
-#else
-       QString extra;
+    if (!d.suicide && qgetenv("KDE_IS_PRELINKED").isEmpty()) {
+        const int extrasCount = sizeof(extra_libs)/sizeof(extra_libs[0]);
+        for (int i=0; i<extrasCount; i++) {
+            QString extra = KStandardDirs::locate("lib", QLatin1String(extra_libs[i]), *s_instance);
+
+            // can't use KLibLoader here as it would unload the library
+            // again
+            if (!extra.isEmpty()) {
+                QLibrary l(extra);
+                l.setLoadHints(QLibrary::ExportExternalSymbolsHint);
+                l.load();
+            }
+#ifndef NDEBUG
+            else {
+                fprintf( stderr, "%s was not found.\n", extra_libs[i] );
+            }
 #endif
-       // can't use KLibLoader here as it would unload the library
-       // again
-       if (!extra.isEmpty()) {
-           QLibrary l(extra);
-           l.setLoadHints(QLibrary::ExportExternalSymbolsHint);
-           l.load();
-       }
-   }
+
+        }
+    }
 #endif
    if (launch_klauncher)
    {
@@ -1785,7 +1837,9 @@ int main(int argc, char **argv, char **envp)
 
    if (launch_kded)
    {
+      setenv("KDED_STARTED_BY_KDEINIT", "1", true);
       pid = launch( 1, KDED_EXENAME, 0 );
+      unsetenv("KDED_STARTED_BY_KDEINIT");
 #ifndef NDEBUG
       fprintf(stderr, "kdeinit4: Launched KDED, pid = %ld result = %d\n", (long) pid, d.result);
 #endif
